@@ -125,97 +125,6 @@ class FsmParseList:
             else:
                 i = i + 1
 
-    def __defaultCaseForParseString(self, rootForm: str, parseString: str, partOfSpeech: str) -> str:
-        """
-        The defaultCaseForParseString method takes String rootForm, parseString and partOfSpeech as inputs. And checks
-        defined cases for parseString and returns the strings till the $ sign. For example, if the given parseString is
-        "A3PL+P3PL+NOM$A3PL+P3SG+NOM$A3PL+PNON+ACC$A3SG+P3PL+NOM" it returns "A3PL+P3SG+NOM".
-
-        PARAMETERS
-        ----------
-        rootForm : str
-            String input.
-        parseString : str
-            String input.
-        partOfSpeech : str
-            String input.
-
-        RETURNS
-        -------
-        str
-            String defaultCase.
-        """
-        if parseString == "P3SG+NOM$PNON+ACC":
-            if partOfSpeech == "PROP":
-                return "PNON+ACC"
-            else:
-                return "P3SG+NOM"
-        elif parseString == "A2SG+P2SG$A3SG+P3SG":
-            return "A3SG+P3SG"
-        elif parseString == "A3PL+P3PL+NOM$A3PL+P3SG+NOM$A3PL+PNON+ACC$A3SG+P3PL+NOM":
-            return "A3PL+P3SG+NOM"
-        elif parseString == "P2SG$P3SG":
-            return "P3SG"
-        elif parseString == "A3PL+PNON+NOM$A3SG+PNON+NOM^DB+VERB+ZERO+PRES+A3PL":
-            return "A3PL+PNON+NOM"
-        elif parseString == "P2SG+NOM$PNON+GEN":
-            return "PNON+GEN"
-        elif parseString == "AOR^DB+ADJ+ZERO$AOR+A3SG":
-            return "AOR+A3SG"
-        elif parseString == "P2SG$PNON":
-            return "PNON"
-        elif parseString == "ADV+SINCE$VERB+ZERO+PRES+COP+A3SG":
-            if rootForm == "yıl" or rootForm == "süre" or rootForm == "zaman" or rootForm == "ay":
-                return "ADV+SINCE"
-            else:
-                return "VERB+ZERO+PRES+COP+A3SG"
-        elif parseString == "CONJ$VERB+POS+IMP+A2SG":
-            return "CONJ"
-        elif parseString == "NEG+IMP+A2SG$POS^DB+NOUN+INF2+A3SG+PNON+NOM":
-            return "POS^DB+NOUN+INF2+A3SG+PNON+NOM"
-        elif parseString == "NEG+OPT+A3SG$POS^DB+NOUN+INF2+A3SG+PNON+DAT":
-            return "POS^DB+NOUN+INF2+A3SG+PNON+DAT"
-        elif parseString == "NOUN+A3SG+P3SG+NOM$NOUN^DB+ADJ+ALMOST":
-            return "NOUN+A3SG+P3SG+NOM"
-        elif parseString == "ADJ$VERB+POS+IMP+A2SG":
-            return "ADJ"
-        elif parseString == "NOUN+A3SG+PNON+NOM$VERB+POS+IMP+A2SG":
-            return "NOUN+A3SG+PNON+NOM"
-        elif parseString == "INF2+A3SG+P3SG+NOM$INF2^DB+ADJ+ALMOST$":
-            return "INF2+A3SG+P3SG+NOM"
-        else:
-            return None
-
-    def caseDisambiguator(self) -> FsmParse:
-        """
-        The caseDisambiguator method first calls the parsesWithoutPrefixAndSuffix method and gets the words without
-        prefixes and suffixes. If the size of fsmParses list is 1, it directly returns the first item of that list and
-        null if the size is 0.
-
-        Then, it calls defaultCaseForParseString method with the root of first item of fsmParses, result of
-        parsesWithoutPrefixAndSuffix method, and the pos of the first item and assigns it result to the defaultCase str.
-        If defaultCase is not null, it then loops through the fsmParses and checks whether the current transitionList of
-        FsmParse contains the defaultCase, if so it returns current FsmParse, null otherwise.
-
-        RETURNS
-        -------
-        FsmParse
-            FsmParse if it contains defaultCase, None otherwise.
-        """
-        parseString = self.parsesWithoutPrefixAndSuffix()
-        if len(self.__fsmParses) == 1:
-            return self.__fsmParses[0]
-        if len(self.__fsmParses) == 0:
-            return None
-        defaultCase = self.__defaultCaseForParseString(self.__fsmParses[0].getWord().getName(), parseString,
-                                                       self.__fsmParses[0].getFinalPos())
-        if defaultCase is not None:
-            for i in range(len(self.__fsmParses)):
-                fsmParse = self.__fsmParses[i]
-                if defaultCase in fsmParse.transitionList():
-                    return fsmParse
-        return None
-
     def constructParseListForDifferentRootWithPos(self) -> list:
         """
         The constructParseListForDifferentRootWithPos method initially creates a result list then loops through the
@@ -301,7 +210,7 @@ class FsmParseList:
                 if analyses[i] > analyses[j]:
                     analyses[i], analyses[j] = analyses[j], analyses[i]
         result = analyses[0]
-        for i in range(len(analyses)):
+        for i in range(1, len(analyses)):
             result = result + "$" + analyses[i]
         return result
 
